/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.annotation.pdfproperties.pdfshape.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatImageView;

import com.compdfkit.tools.R;

import java.util.Arrays;
import java.util.List;


public class CShapeStyleSpinnerAdapter extends BaseAdapter {

    public enum ShapeStyle{
        Straight_Line,

        Squiggly_Line
    }

    public List<ShapeStyle> list;

    private Context mContext;

    private ShapeStyle selectStyleType;

    public CShapeStyleSpinnerAdapter(@NonNull Context context) {
        this.list = Arrays.asList(ShapeStyle.Straight_Line, ShapeStyle.Squiggly_Line);
        mContext = context;
    }

    public void setSelectStyleType(ShapeStyle selectStyleType) {
        this.selectStyleType = selectStyleType;
    }

    public int getSelectPosition(){
        if (selectStyleType != null){
            for (int i = 0; i < list.size(); i++) {
                ShapeStyle item = list.get(i);
                if (selectStyleType.equals(item)) {
                    return i;
                }
            }
        }
        return 0;
    }

    public ShapeStyle getSelectShapeType(){
        if (selectStyleType != null){
            return selectStyleType;
        }
        return ShapeStyle.Straight_Line;
    }

    @Override
    public int getCount() {
        return list.size();
    }

    @Override
    public Object getItem(int position) {
        return list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        CShapeStyleViewHolder holder;

        if (convertView == null){
            LayoutInflater inflater = LayoutInflater.from(mContext);
            convertView = inflater.inflate(R.layout.tools_spinner_list_image_item, null);
            holder = new CShapeStyleViewHolder();
            holder.ivShapeStyle = convertView.findViewById(R.id.iv_image_menu);
            convertView.setTag(holder);
        }else {
            holder = (CShapeStyleViewHolder) convertView.getTag();
        }
        ShapeStyle shapeStyle = list.get(position);
        holder.ivShapeStyle.setImageResource(shapeStyle == ShapeStyle.Straight_Line ? R.drawable.tools_line_type_straight_line : R.drawable.tools_line_type_squiggly);
        return convertView;
    }

    static class CShapeStyleViewHolder{
        AppCompatImageView ivShapeStyle;
    }
}
